@@ -1,13 +1,18 @@
 #' @title Generate text from text with Gemini
 #' @description Generate text from text with Gemini
 #' @param prompt The prompt to generate text from
-#' @param model The model to use. Options are '1.5-flash', '1.5-pro', '1.0-pro' and '2.0-flash-exp'. Default is '1.5-flash'
+#' @param model The model to use. Options are "2.0-flash", "2.0-flash-lite", "1.5-flash", "1.5-flash-8b", "1.5-pro", Default is '2.0-flash'
 #'              see https://ai.google.dev/gemini-api/docs/models/gemini
-#' @param temperature The temperature to use. Default is 0.5 value should be between 0 and 2
+#' @param temperature The temperature to use. Default is 1 value should be between 0 and 2
+#'              see https://ai.google.dev/gemini-api/docs/models/generative-models#model-parameters
+#' @param topP The top-p value to use. Default is 0.95 value should be between 0 and 1
+#'              see https://ai.google.dev/gemini-api/docs/models/generative-models#model-parameters
+#' @param topK The top-k value to use. Default is 40 value should be between 0 and 100
+#'              see https://ai.google.dev/gemini-api/docs/models/generative-models#model-parameters
+#' @param seed The seed to use. Default is 1234 value should be integer
 #'              see https://ai.google.dev/gemini-api/docs/models/generative-models#model-parameters
 #' @param maxOutputTokens The maximum number of tokens to generate.
-#'              Default is 1024 and 100 tokens correspond to roughly 60-80 words.
-#'
+#'              Default is 8192 and 100 tokens correspond to roughly 60-80 words.
 #' @return Generated text
 #' @export
 #' @examples
@@ -22,7 +27,7 @@
 #' @seealso https://ai.google.dev/docs/gemini_api_overview#text_input
 #'
 
-gemini <- function(prompt, model = "1.5-flash", temperature = 0.5, maxOutputTokens = 1024) {
+gemini <- function(prompt, model = "2.0-flash", temperature = 1, maxOutputTokens = 8192, topK = 40, topP = 0.95, seed = 1234) {
   if (is.null(prompt)) {
     cli_alert_danger("{.arg prompt} must not NULL")
     return(NULL)
@@ -33,26 +38,39 @@ gemini <- function(prompt, model = "1.5-flash", temperature = 0.5, maxOutputToke
     return(NULL)
   }
 
+  # API Key
   if (Sys.getenv("GEMINI_API_KEY") == "") {
     cli_alert_danger("Please set the {.envvar GEMINI_API_KEY} with {.fn setAPI} function.")
     return(NULL)
   }
 
-  if (!(model %in% c("1.5-flash", "1.5-pro", "1.0-pro", "2.0-flash-exp"))) {
-    cli_alert_danger("Error: Parameter 'model' must be one of '1.5-flash', '1.5-pro', '1.0-pro', '2.0-flash-exp")
+  # Model
+  if (!(model %in% c("2.0-flash", "2.0-flash-lite", "1.5-flash", "1.5-flash-8b", "1.5-pro"))) {
+    cli_alert_danger("Error: Parameter 'model' must be one of '2.0-flash', '2.0-flash-lite', '1.5-flash', '1.5-flash-8b', '1.5-pro'")
     return(NULL)
   }
 
+  model_query <- paste0("gemini-", model, ":generateContent")
+
+  # Parameters
   if (temperature < 0 | temperature > 2) {
     cli_alert_danger("Error: Parameter 'temperature' must be between 0 and 2")
     return(NULL)
   }
 
-  if (model == "2.0-flash-exp") {
-    # exp is included, so remove -latest tag
-    model_query <- paste0("gemini-", model, ":generateContent")
-  } else {
-    model_query <- paste0("gemini-", model, "-latest:generateContent")
+  if (topP < 0 | topP > 1) {
+    cli_alert_danger("Error: Parameter 'topP' must be between 0 and 1")
+    return(NULL)
+  }
+
+  if (topK < 0 | topK > 100) {
+    cli_alert_danger("Error: Parameter 'topK' must be between 0 and 100")
+    return(NULL)
+  }
+
+  if (!is.numeric(seed) || seed %% 1 != 0) {
+    cli_alert_danger("Error: Parameter 'seed' must be an integer")
+    return(NULL)
   }
 
   url <- paste0("https://generativelanguage.googleapis.com/v1beta/models/", model_query)
@@ -70,12 +88,15 @@ gemini <- function(prompt, model = "1.5-flash", temperature = 0.5, maxOutputToke
           list(text = prompt)
         )
       ),
-      generationConfig = list(
-        temperature = temperature,
-        maxOutputTokens = maxOutputTokens
-      )
+      generationConfig =
+        list(
+          temperature = temperature,
+          maxOutputTokens = maxOutputTokens,
+          topP = topP,
+          topK = topK,
+          seed = seed
+        )
     ))
-
   resp <- req_perform(req)
 
   cli_status_clear(id = sb)
@@ -91,6 +112,16 @@ gemini <- function(prompt, model = "1.5-flash", temperature = 0.5, maxOutputToke
 #'
 #' @param prompt A character string containing the prompt for the Gemini model.
 #' @param tokens A list containing the API URL and key from token.vertex() function.
+#' @param temperature The temperature to use. Default is 1 value should be between 0 and 2
+#'              see https://ai.google.dev/gemini-api/docs/models/generative-models#model-parameters
+#' @param maxOutputTokens The maximum number of tokens to generate.
+#'              Default is 8192 and 100 tokens correspond to roughly 60-80 words.
+#' @param topK The top-k value to use. Default is 40 value should be between 0 and 100
+#'              see https://ai.google.dev/gemini-api/docs/models/generative-models#model-parameters
+#' @param topP The top-p value to use. Default is 0.95 value should be between 0 and 1
+#'              see https://ai.google.dev/gemini-api/docs/models/generative-models#model-parameters
+#' @param seed The seed to use. Default is 1234 value should be integer
+#'              see https://ai.google.dev/gemini-api/docs/models/generative-models#model-parameters
 #'
 #' @examples
 #' \dontrun{
@@ -100,13 +131,14 @@ gemini <- function(prompt, model = "1.5-flash", temperature = 0.5, maxOutputToke
 #' }
 #'
 #' @seealso https://ai.google.dev/docs/gemini_api_overview#text_input
-#' @return #' A character string containing the generated text.
+#' @return A character string containing the generated text.
 #' @importFrom httr2 request req_headers req_body_json req_perform resp_body_json
 #'
 #' @export
 
-gemini.vertex <- function(prompt = NULL, tokens = NULL){
-  if(is.null(prompt)){
+gemini.vertex <- function(prompt = NULL, tokens = NULL, temperature = 1, maxOutputTokens = 8192,
+                          topK = 40, topP = 0.95, seed = 1234) {
+  if (is.null(prompt)) {
     cli_alert_danger("{.arg prompt} must not NULL")
     return(NULL)
   }
@@ -116,6 +148,32 @@ gemini.vertex <- function(prompt = NULL, tokens = NULL){
     return(NULL)
   }
 
+  if (is.null(tokens)) {
+    cli_alert_danger("{.arg tokens} must not be NULL. Use token.vertex() function to generate tokens.")
+    return(NULL)
+  }
+
+  # Parameters validation
+  if (temperature < 0 | temperature > 2) {
+    cli_alert_danger("Error: Parameter 'temperature' must be between 0 and 2")
+    return(NULL)
+  }
+
+  if (topP < 0 | topP > 1) {
+    cli_alert_danger("Error: Parameter 'topP' must be between 0 and 1")
+    return(NULL)
+  }
+
+  if (topK < 0 | topK > 100) {
+    cli_alert_danger("Error: Parameter 'topK' must be between 0 and 100")
+    return(NULL)
+  }
+
+  if (!is.numeric(seed) || seed %% 1 != 0) {
+    cli_alert_danger("Error: Parameter 'seed' must be an integer")
+    return(NULL)
+  }
+
   request_body <- list(
     contents = list(
       list(
@@ -124,6 +182,13 @@ gemini.vertex <- function(prompt = NULL, tokens = NULL){
           list(text = prompt)
         )
       )
+    ),
+    generationConfig = list(
+      temperature = temperature,
+      maxOutputTokens = maxOutputTokens,
+      topP = topP,
+      topK = topK,
+      seed = seed
     )
   )
 
